"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import cosmos.tx.v1beta1.service_pb2
import grpc

class ServiceStub:
    """Service defines a gRPC service for interacting with transactions."""

    def __init__(self, channel: grpc.Channel) -> None: ...
    Simulate: grpc.UnaryUnaryMultiCallable[
        cosmos.tx.v1beta1.service_pb2.SimulateRequest,
        cosmos.tx.v1beta1.service_pb2.SimulateResponse,
    ]
    """Simulate simulates executing a transaction for estimating gas usage."""
    GetTx: grpc.UnaryUnaryMultiCallable[
        cosmos.tx.v1beta1.service_pb2.GetTxRequest,
        cosmos.tx.v1beta1.service_pb2.GetTxResponse,
    ]
    """GetTx fetches a tx by hash."""
    BroadcastTx: grpc.UnaryUnaryMultiCallable[
        cosmos.tx.v1beta1.service_pb2.BroadcastTxRequest,
        cosmos.tx.v1beta1.service_pb2.BroadcastTxResponse,
    ]
    """BroadcastTx broadcast transaction."""
    GetTxsEvent: grpc.UnaryUnaryMultiCallable[
        cosmos.tx.v1beta1.service_pb2.GetTxsEventRequest,
        cosmos.tx.v1beta1.service_pb2.GetTxsEventResponse,
    ]
    """GetTxsEvent fetches txs by event."""

class ServiceServicer(metaclass=abc.ABCMeta):
    """Service defines a gRPC service for interacting with transactions."""

    @abc.abstractmethod
    def Simulate(
        self,
        request: cosmos.tx.v1beta1.service_pb2.SimulateRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.tx.v1beta1.service_pb2.SimulateResponse:
        """Simulate simulates executing a transaction for estimating gas usage."""
    @abc.abstractmethod
    def GetTx(
        self,
        request: cosmos.tx.v1beta1.service_pb2.GetTxRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.tx.v1beta1.service_pb2.GetTxResponse:
        """GetTx fetches a tx by hash."""
    @abc.abstractmethod
    def BroadcastTx(
        self,
        request: cosmos.tx.v1beta1.service_pb2.BroadcastTxRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.tx.v1beta1.service_pb2.BroadcastTxResponse:
        """BroadcastTx broadcast transaction."""
    @abc.abstractmethod
    def GetTxsEvent(
        self,
        request: cosmos.tx.v1beta1.service_pb2.GetTxsEventRequest,
        context: grpc.ServicerContext,
    ) -> cosmos.tx.v1beta1.service_pb2.GetTxsEventResponse:
        """GetTxsEvent fetches txs by event."""

def add_ServiceServicer_to_server(servicer: ServiceServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import tendermint.abci.types_pb2

class ABCIApplicationStub:
    """----------------------------------------
    Service Definition
    """

    def __init__(self, channel: grpc.Channel) -> None: ...
    Echo: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestEcho,
        tendermint.abci.types_pb2.ResponseEcho,
    ]
    Flush: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestFlush,
        tendermint.abci.types_pb2.ResponseFlush,
    ]
    Info: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestInfo,
        tendermint.abci.types_pb2.ResponseInfo,
    ]
    SetOption: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestSetOption,
        tendermint.abci.types_pb2.ResponseSetOption,
    ]
    DeliverTx: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestDeliverTx,
        tendermint.abci.types_pb2.ResponseDeliverTx,
    ]
    CheckTx: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestCheckTx,
        tendermint.abci.types_pb2.ResponseCheckTx,
    ]
    Query: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestQuery,
        tendermint.abci.types_pb2.ResponseQuery,
    ]
    Commit: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestCommit,
        tendermint.abci.types_pb2.ResponseCommit,
    ]
    InitChain: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestInitChain,
        tendermint.abci.types_pb2.ResponseInitChain,
    ]
    BeginBlock: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestBeginBlock,
        tendermint.abci.types_pb2.ResponseBeginBlock,
    ]
    EndBlock: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestEndBlock,
        tendermint.abci.types_pb2.ResponseEndBlock,
    ]
    ListSnapshots: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestListSnapshots,
        tendermint.abci.types_pb2.ResponseListSnapshots,
    ]
    OfferSnapshot: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestOfferSnapshot,
        tendermint.abci.types_pb2.ResponseOfferSnapshot,
    ]
    LoadSnapshotChunk: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestLoadSnapshotChunk,
        tendermint.abci.types_pb2.ResponseLoadSnapshotChunk,
    ]
    ApplySnapshotChunk: grpc.UnaryUnaryMultiCallable[
        tendermint.abci.types_pb2.RequestApplySnapshotChunk,
        tendermint.abci.types_pb2.ResponseApplySnapshotChunk,
    ]

class ABCIApplicationServicer(metaclass=abc.ABCMeta):
    """----------------------------------------
    Service Definition
    """

    @abc.abstractmethod
    def Echo(
        self,
        request: tendermint.abci.types_pb2.RequestEcho,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseEcho: ...
    @abc.abstractmethod
    def Flush(
        self,
        request: tendermint.abci.types_pb2.RequestFlush,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseFlush: ...
    @abc.abstractmethod
    def Info(
        self,
        request: tendermint.abci.types_pb2.RequestInfo,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseInfo: ...
    @abc.abstractmethod
    def SetOption(
        self,
        request: tendermint.abci.types_pb2.RequestSetOption,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseSetOption: ...
    @abc.abstractmethod
    def DeliverTx(
        self,
        request: tendermint.abci.types_pb2.RequestDeliverTx,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseDeliverTx: ...
    @abc.abstractmethod
    def CheckTx(
        self,
        request: tendermint.abci.types_pb2.RequestCheckTx,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseCheckTx: ...
    @abc.abstractmethod
    def Query(
        self,
        request: tendermint.abci.types_pb2.RequestQuery,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseQuery: ...
    @abc.abstractmethod
    def Commit(
        self,
        request: tendermint.abci.types_pb2.RequestCommit,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseCommit: ...
    @abc.abstractmethod
    def InitChain(
        self,
        request: tendermint.abci.types_pb2.RequestInitChain,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseInitChain: ...
    @abc.abstractmethod
    def BeginBlock(
        self,
        request: tendermint.abci.types_pb2.RequestBeginBlock,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseBeginBlock: ...
    @abc.abstractmethod
    def EndBlock(
        self,
        request: tendermint.abci.types_pb2.RequestEndBlock,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseEndBlock: ...
    @abc.abstractmethod
    def ListSnapshots(
        self,
        request: tendermint.abci.types_pb2.RequestListSnapshots,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseListSnapshots: ...
    @abc.abstractmethod
    def OfferSnapshot(
        self,
        request: tendermint.abci.types_pb2.RequestOfferSnapshot,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseOfferSnapshot: ...
    @abc.abstractmethod
    def LoadSnapshotChunk(
        self,
        request: tendermint.abci.types_pb2.RequestLoadSnapshotChunk,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseLoadSnapshotChunk: ...
    @abc.abstractmethod
    def ApplySnapshotChunk(
        self,
        request: tendermint.abci.types_pb2.RequestApplySnapshotChunk,
        context: grpc.ServicerContext,
    ) -> tendermint.abci.types_pb2.ResponseApplySnapshotChunk: ...

def add_ABCIApplicationServicer_to_server(servicer: ABCIApplicationServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc
import osmosis.gamm.v1beta1.query_pb2

class QueryStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    Pools: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryPoolsRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryPoolsResponse,
    ]
    NumPools: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryNumPoolsRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryNumPoolsResponse,
    ]
    TotalLiquidity: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryTotalLiquidityRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryTotalLiquidityResponse,
    ]
    PoolsWithFilter: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryPoolsWithFilterRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryPoolsWithFilterResponse,
    ]
    """PoolsWithFilter allows you to query specific pools with requested
    parameters
    """
    Pool: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryPoolRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryPoolResponse,
    ]
    """Per Pool gRPC Endpoints"""
    PoolType: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryPoolTypeRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryPoolTypeResponse,
    ]
    """PoolType returns the type of the pool.
    Returns "Balancer" as a string literal when the pool is a balancer pool.
    Errors if the pool is failed to be type caseted.
    """
    CalcJoinPoolNoSwapShares: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryCalcJoinPoolNoSwapSharesRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryCalcJoinPoolNoSwapSharesResponse,
    ]
    """Simulates joining pool without a swap. Returns the amount of shares you'd
    get and tokens needed to provide
    """
    CalcJoinPoolShares: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryCalcJoinPoolSharesRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryCalcJoinPoolSharesResponse,
    ]
    CalcExitPoolCoinsFromShares: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryCalcExitPoolCoinsFromSharesRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryCalcExitPoolCoinsFromSharesResponse,
    ]
    PoolParams: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryPoolParamsRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryPoolParamsResponse,
    ]
    TotalPoolLiquidity: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryTotalPoolLiquidityRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryTotalPoolLiquidityResponse,
    ]
    TotalShares: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QueryTotalSharesRequest,
        osmosis.gamm.v1beta1.query_pb2.QueryTotalSharesResponse,
    ]
    SpotPrice: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QuerySpotPriceRequest,
        osmosis.gamm.v1beta1.query_pb2.QuerySpotPriceResponse,
    ]
    """SpotPrice defines a gRPC query handler that returns the spot price given
    a base denomination and a quote denomination.
    """
    EstimateSwapExactAmountIn: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QuerySwapExactAmountInRequest,
        osmosis.gamm.v1beta1.query_pb2.QuerySwapExactAmountInResponse,
    ]
    """Estimate the swap."""
    EstimateSwapExactAmountOut: grpc.UnaryUnaryMultiCallable[
        osmosis.gamm.v1beta1.query_pb2.QuerySwapExactAmountOutRequest,
        osmosis.gamm.v1beta1.query_pb2.QuerySwapExactAmountOutResponse,
    ]

class QueryServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def Pools(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryPoolsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryPoolsResponse: ...
    @abc.abstractmethod
    def NumPools(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryNumPoolsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryNumPoolsResponse: ...
    @abc.abstractmethod
    def TotalLiquidity(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryTotalLiquidityRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryTotalLiquidityResponse: ...
    @abc.abstractmethod
    def PoolsWithFilter(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryPoolsWithFilterRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryPoolsWithFilterResponse:
        """PoolsWithFilter allows you to query specific pools with requested
        parameters
        """
    @abc.abstractmethod
    def Pool(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryPoolRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryPoolResponse:
        """Per Pool gRPC Endpoints"""
    @abc.abstractmethod
    def PoolType(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryPoolTypeRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryPoolTypeResponse:
        """PoolType returns the type of the pool.
        Returns "Balancer" as a string literal when the pool is a balancer pool.
        Errors if the pool is failed to be type caseted.
        """
    @abc.abstractmethod
    def CalcJoinPoolNoSwapShares(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryCalcJoinPoolNoSwapSharesRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryCalcJoinPoolNoSwapSharesResponse:
        """Simulates joining pool without a swap. Returns the amount of shares you'd
        get and tokens needed to provide
        """
    @abc.abstractmethod
    def CalcJoinPoolShares(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryCalcJoinPoolSharesRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryCalcJoinPoolSharesResponse: ...
    @abc.abstractmethod
    def CalcExitPoolCoinsFromShares(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryCalcExitPoolCoinsFromSharesRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryCalcExitPoolCoinsFromSharesResponse: ...
    @abc.abstractmethod
    def PoolParams(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryPoolParamsRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryPoolParamsResponse: ...
    @abc.abstractmethod
    def TotalPoolLiquidity(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryTotalPoolLiquidityRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryTotalPoolLiquidityResponse: ...
    @abc.abstractmethod
    def TotalShares(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QueryTotalSharesRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QueryTotalSharesResponse: ...
    @abc.abstractmethod
    def SpotPrice(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QuerySpotPriceRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QuerySpotPriceResponse:
        """SpotPrice defines a gRPC query handler that returns the spot price given
        a base denomination and a quote denomination.
        """
    @abc.abstractmethod
    def EstimateSwapExactAmountIn(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QuerySwapExactAmountInRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QuerySwapExactAmountInResponse:
        """Estimate the swap."""
    @abc.abstractmethod
    def EstimateSwapExactAmountOut(
        self,
        request: osmosis.gamm.v1beta1.query_pb2.QuerySwapExactAmountOutRequest,
        context: grpc.ServicerContext,
    ) -> osmosis.gamm.v1beta1.query_pb2.QuerySwapExactAmountOutResponse: ...

def add_QueryServicer_to_server(servicer: QueryServicer, server: grpc.Server) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys
import tendermint.crypto.keys_pb2

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ValidatorSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALIDATORS_FIELD_NUMBER: builtins.int
    PROPOSER_FIELD_NUMBER: builtins.int
    TOTAL_VOTING_POWER_FIELD_NUMBER: builtins.int
    @property
    def validators(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Validator]: ...
    @property
    def proposer(self) -> global___Validator: ...
    total_voting_power: builtins.int
    def __init__(
        self,
        *,
        validators: collections.abc.Iterable[global___Validator] | None = ...,
        proposer: global___Validator | None = ...,
        total_voting_power: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["proposer", b"proposer"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["proposer", b"proposer", "total_voting_power", b"total_voting_power", "validators", b"validators"]) -> None: ...

global___ValidatorSet = ValidatorSet

@typing_extensions.final
class Validator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_FIELD_NUMBER: builtins.int
    PUB_KEY_FIELD_NUMBER: builtins.int
    VOTING_POWER_FIELD_NUMBER: builtins.int
    PROPOSER_PRIORITY_FIELD_NUMBER: builtins.int
    address: builtins.bytes
    @property
    def pub_key(self) -> tendermint.crypto.keys_pb2.PublicKey: ...
    voting_power: builtins.int
    proposer_priority: builtins.int
    def __init__(
        self,
        *,
        address: builtins.bytes = ...,
        pub_key: tendermint.crypto.keys_pb2.PublicKey | None = ...,
        voting_power: builtins.int = ...,
        proposer_priority: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pub_key", b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address", b"address", "proposer_priority", b"proposer_priority", "pub_key", b"pub_key", "voting_power", b"voting_power"]) -> None: ...

global___Validator = Validator

@typing_extensions.final
class SimpleValidator(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUB_KEY_FIELD_NUMBER: builtins.int
    VOTING_POWER_FIELD_NUMBER: builtins.int
    @property
    def pub_key(self) -> tendermint.crypto.keys_pb2.PublicKey: ...
    voting_power: builtins.int
    def __init__(
        self,
        *,
        pub_key: tendermint.crypto.keys_pb2.PublicKey | None = ...,
        voting_power: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pub_key", b"pub_key"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["pub_key", b"pub_key", "voting_power", b"voting_power"]) -> None: ...

global___SimpleValidator = SimpleValidator



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from osmosis.incentives import tx_pb2 as osmosis_dot_incentives_dot_tx__pb2


class MsgStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateGauge = channel.unary_unary(
                '/osmosis.incentives.Msg/CreateGauge',
                request_serializer=osmosis_dot_incentives_dot_tx__pb2.MsgCreateGauge.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_tx__pb2.MsgCreateGaugeResponse.FromString,
                )
        self.AddToGauge = channel.unary_unary(
                '/osmosis.incentives.Msg/AddToGauge',
                request_serializer=osmosis_dot_incentives_dot_tx__pb2.MsgAddToGauge.SerializeToString,
                response_deserializer=osmosis_dot_incentives_dot_tx__pb2.MsgAddToGaugeResponse.FromString,
                )


class MsgServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateGauge(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddToGauge(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MsgServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateGauge': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateGauge,
                    request_deserializer=osmosis_dot_incentives_dot_tx__pb2.MsgCreateGauge.FromString,
                    response_serializer=osmosis_dot_incentives_dot_tx__pb2.MsgCreateGaugeResponse.SerializeToString,
            ),
            'AddToGauge': grpc.unary_unary_rpc_method_handler(
                    servicer.AddToGauge,
                    request_deserializer=osmosis_dot_incentives_dot_tx__pb2.MsgAddToGauge.FromString,
                    response_serializer=osmosis_dot_incentives_dot_tx__pb2.MsgAddToGaugeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'osmosis.incentives.Msg', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Msg(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateGauge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Msg/CreateGauge',
            osmosis_dot_incentives_dot_tx__pb2.MsgCreateGauge.SerializeToString,
            osmosis_dot_incentives_dot_tx__pb2.MsgCreateGaugeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddToGauge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/osmosis.incentives.Msg/AddToGauge',
            osmosis_dot_incentives_dot_tx__pb2.MsgAddToGauge.SerializeToString,
            osmosis_dot_incentives_dot_tx__pb2.MsgAddToGaugeResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: osmosis/superfluid/genesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gogoproto import gogo_pb2 as gogoproto_dot_gogo__pb2
from osmosis.superfluid import superfluid_pb2 as osmosis_dot_superfluid_dot_superfluid__pb2
from osmosis.superfluid import params_pb2 as osmosis_dot_superfluid_dot_params__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n osmosis/superfluid/genesis.proto\x12\x12osmosis.superfluid\x1a\x14gogoproto/gogo.proto\x1a#osmosis/superfluid/superfluid.proto\x1a\x1fosmosis/superfluid/params.proto\"\xa5\x03\n\x0cGenesisState\x12\x30\n\x06params\x18\x01 \x01(\x0b\x32\x1a.osmosis.superfluid.ParamsB\x04\xc8\xde\x1f\x00\x12\x44\n\x11superfluid_assets\x18\x02 \x03(\x0b\x32#.osmosis.superfluid.SuperfluidAssetB\x04\xc8\xde\x1f\x00\x12]\n\x1bosmo_equivalent_multipliers\x18\x03 \x03(\x0b\x32\x32.osmosis.superfluid.OsmoEquivalentMultiplierRecordB\x04\xc8\xde\x1f\x00\x12V\n\x15intermediary_accounts\x18\x04 \x03(\x0b\x32\x31.osmosis.superfluid.SuperfluidIntermediaryAccountB\x04\xc8\xde\x1f\x00\x12\x66\n\x1fintemediary_account_connections\x18\x05 \x03(\x0b\x32\x37.osmosis.superfluid.LockIdIntermediaryAccountConnectionB\x04\xc8\xde\x1f\x00\x42\x38Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/typesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'osmosis.superfluid.genesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z6github.com/osmosis-labs/osmosis/v14/x/superfluid/types'
  _GENESISSTATE.fields_by_name['params']._options = None
  _GENESISSTATE.fields_by_name['params']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['superfluid_assets']._options = None
  _GENESISSTATE.fields_by_name['superfluid_assets']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['osmo_equivalent_multipliers']._options = None
  _GENESISSTATE.fields_by_name['osmo_equivalent_multipliers']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['intermediary_accounts']._options = None
  _GENESISSTATE.fields_by_name['intermediary_accounts']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE.fields_by_name['intemediary_account_connections']._options = None
  _GENESISSTATE.fields_by_name['intemediary_account_connections']._serialized_options = b'\310\336\037\000'
  _GENESISSTATE._serialized_start=149
  _GENESISSTATE._serialized_end=570
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import osmosis.superfluid.params_pb2
import osmosis.superfluid.superfluid_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GenesisState(google.protobuf.message.Message):
    """GenesisState defines the module's genesis state."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARAMS_FIELD_NUMBER: builtins.int
    SUPERFLUID_ASSETS_FIELD_NUMBER: builtins.int
    OSMO_EQUIVALENT_MULTIPLIERS_FIELD_NUMBER: builtins.int
    INTERMEDIARY_ACCOUNTS_FIELD_NUMBER: builtins.int
    INTEMEDIARY_ACCOUNT_CONNECTIONS_FIELD_NUMBER: builtins.int
    @property
    def params(self) -> osmosis.superfluid.params_pb2.Params: ...
    @property
    def superfluid_assets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.superfluid.superfluid_pb2.SuperfluidAsset]:
        """superfluid_assets defines the registered superfluid assets that have been
        registered via governance.
        """
    @property
    def osmo_equivalent_multipliers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.superfluid.superfluid_pb2.OsmoEquivalentMultiplierRecord]:
        """osmo_equivalent_multipliers is the records of osmo equivalent amount of
        each superfluid registered pool, updated every epoch.
        """
    @property
    def intermediary_accounts(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.superfluid.superfluid_pb2.SuperfluidIntermediaryAccount]:
        """intermediary_accounts is a secondary account for superfluid staking that
        plays an intermediary role between validators and the delegators.
        """
    @property
    def intemediary_account_connections(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[osmosis.superfluid.superfluid_pb2.LockIdIntermediaryAccountConnection]: ...
    def __init__(
        self,
        *,
        params: osmosis.superfluid.params_pb2.Params | None = ...,
        superfluid_assets: collections.abc.Iterable[osmosis.superfluid.superfluid_pb2.SuperfluidAsset] | None = ...,
        osmo_equivalent_multipliers: collections.abc.Iterable[osmosis.superfluid.superfluid_pb2.OsmoEquivalentMultiplierRecord] | None = ...,
        intermediary_accounts: collections.abc.Iterable[osmosis.superfluid.superfluid_pb2.SuperfluidIntermediaryAccount] | None = ...,
        intemediary_account_connections: collections.abc.Iterable[osmosis.superfluid.superfluid_pb2.LockIdIntermediaryAccountConnection] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["params", b"params"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["intemediary_account_connections", b"intemediary_account_connections", "intermediary_accounts", b"intermediary_accounts", "osmo_equivalent_multipliers", b"osmo_equivalent_multipliers", "params", b"params", "superfluid_assets", b"superfluid_assets"]) -> None: ...

global___GenesisState = GenesisState



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Node(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHILDREN_FIELD_NUMBER: builtins.int
    @property
    def children(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Child]: ...
    def __init__(
        self,
        *,
        children: collections.abc.Iterable[global___Child] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["children", b"children"]) -> None: ...

global___Node = Node

@typing_extensions.final
class Child(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INDEX_FIELD_NUMBER: builtins.int
    ACCUMULATION_FIELD_NUMBER: builtins.int
    index: builtins.bytes
    accumulation: builtins.str
    def __init__(
        self,
        *,
        index: builtins.bytes = ...,
        accumulation: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accumulation", b"accumulation", "index", b"index"]) -> None: ...

global___Child = Child

@typing_extensions.final
class Leaf(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEAF_FIELD_NUMBER: builtins.int
    @property
    def leaf(self) -> global___Child: ...
    def __init__(
        self,
        *,
        leaf: global___Child | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["leaf", b"leaf"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["leaf", b"leaf"]) -> None: ...

global___Leaf = Leaf
